==> ah-formbuilder-1.0.92.tgz: package/es/components/toolbar/EditField.js <==
var _jsxFileName = "/home/zaman/Documents/GitLab/bayt/formbuilder/src/components/toolbar/EditField.js";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React from 'react';
import { connect } from "react-redux";
import TextField from "./field-forms/TextField";
import Checkbox from "./field-forms/Checkbox";
import Content from "./field-forms/Content";
import Date from "./field-forms/Date";
import File from "./field-forms/File";
import Image from "./field-forms/Image";
import List from "./field-forms/List";
import Quiz from "./field-forms/Quiz";
import Select from "./field-forms/Select";
import Signature from "./field-forms/Signature";
import Survey from "./field-forms/Survey";
import Video from "./field-forms/Video";
import Radio from "./field-forms/Radio";
import Section from "./field-forms/Section";
import _ from 'lodash';

function EditField(props) {
  var _props$data$editId,
      _props$allRoles,
      _this = this;

  var field = {};

  if (props.newFieldData) {
    field = _.cloneDeep(props.newFieldData);
  } else {
    field = _.cloneDeep(props.data[props.editId]);
    if (field.locals && Object.keys(field.locals).length) Object.keys(field.locals).forEach(function (local) {
      if (local && Object.keys(local).length) field.config = _extends({}, field.config, {}, field.locals[local]);
    });
  }

  var editId = (props == null ? void 0 : props.editId) || "83b39886-da74-4654-ae7d-e4d427082d48";
  var hiddenRoles = (_props$data$editId = props.data[editId]) == null ? void 0 : _props$data$editId.hiddenRoles;
  var updatedRoles = [];
  (_props$allRoles = props.allRoles) == null ? void 0 : _props$allRoles.forEach(function (role) {
    updatedRoles.push(_extends({}, role, {
      label: role == null ? void 0 : role.name,
      value: role == null ? void 0 : role.id
    }));
  });

  var renderFieldForms = function renderFieldForms() {
    switch (field.type) {
      case 'checkbox':
        return /*#__PURE__*/React.createElement(Checkbox, {
          data: field,
          allRoles: updatedRoles,
          hiddenRoles: hiddenRoles,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 42,
            columnNumber: 11
          }
        });

      case 'radio':
        return /*#__PURE__*/React.createElement(Radio, {
          data: field,
          allRoles: updatedRoles,
          hiddenRoles: hiddenRoles,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 46,
            columnNumber: 11
          }
        });

      case 'content':
        return /*#__PURE__*/React.createElement(Content, {
          data: field,
          allRoles: updatedRoles,
          hiddenRoles: hiddenRoles,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 50,
            columnNumber: 13
          }
        });

      case 'date':
        return /*#__PURE__*/React.createElement(Date, {
          data: field,
          allRoles: updatedRoles,
          hiddenRoles: hiddenRoles,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 54,
            columnNumber: 13
          }
        });

      case 'file':
        return /*#__PURE__*/React.createElement(File, {
          data: field,
          allRoles: updatedRoles,
          hiddenRoles: hiddenRoles,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 58,
            columnNumber: 13
          }
        });

      case 'image':
        return /*#__PURE__*/React.createElement(Image, {
          data: field,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 62,
            columnNumber: 13
          }
        });

      case 'list':
        return /*#__PURE__*/React.createElement(List, {
          data: field,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 66,
            columnNumber: 13
          }
        });

      case 'quiz':
        return /*#__PURE__*/React.createElement(Quiz, {
          data: field,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 70,
            columnNumber: 13
          }
        });

      case 'select':
        return /*#__PURE__*/React.createElement(Select, {
          data: field,
          allRoles: updatedRoles,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 74,
            columnNumber: 13
          }
        });

      case 'signature':
        return /*#__PURE__*/React.createElement(Signature, {
          data: field,
          allRoles: updatedRoles,
          hiddenRoles: hiddenRoles,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 78,
            columnNumber: 13
          }
        });

      case 'survey':
        return /*#__PURE__*/React.createElement(Survey, {
          data: field,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 82,
            columnNumber: 13
          }
        });

      case 'text':
        return /*#__PURE__*/React.createElement(TextField, {
          data: field,
          allRoles: updatedRoles,
          hiddenRoles: hiddenRoles,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 86,
            columnNumber: 13
          }
        });

      case 'video':
        return /*#__PURE__*/React.createElement(Video, {
          data: field,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 90,
            columnNumber: 13
          }
        });

      case 'section':
        return /*#__PURE__*/React.createElement(Section, {
          data: field,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 93,
            columnNumber: 16
          }
        });

      default:
        return /*#__PURE__*/React.createElement("div", {
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 96,
            columnNumber: 11
          }
        }, "Something magical happened");
    }
  };

  return /*#__PURE__*/React.createElement("div", {
    className: "position-relative ahfb-width-full",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 101,
      columnNumber: 5
    }
  }, renderFieldForms());
}

var mapStateToProps = function mapStateToProps(state) {
  return {
    newFieldData: state.form.newFieldData,
    editId: state.toolbar.editId,
    data: state.form.data,
    allRoles: state.form.allRoles
  };
};

var mapDispatchToProps = function mapDispatchToProps(dispatch) {
  return {};
};

export default connect(mapStateToProps, mapDispatchToProps)(EditField);

==> ah-formbuilder-1.0.97.tgz: package/es/components/toolbar/EditField.js <==
var _jsxFileName = "/home/zaman/Documents/GitLab/bayt/formbuilder/src/components/toolbar/EditField.js";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React from 'react';
import { connect } from "react-redux";
import TextField from "./field-forms/TextField";
import Checkbox from "./field-forms/Checkbox";
import Content from "./field-forms/Content";
import Date from "./field-forms/Date";
import File from "./field-forms/File";
import Image from "./field-forms/Image";
import List from "./field-forms/List";
import Quiz from "./field-forms/Quiz";
import Select from "./field-forms/Select";
import Signature from "./field-forms/Signature";
import Survey from "./field-forms/Survey";
import Video from "./field-forms/Video";
import Radio from "./field-forms/Radio";
import Section from "./field-forms/Section";
import _ from 'lodash';

function EditField(props) {
  var _props$data,
      _props$data$editId,
      _props$data$editId$co,
      _props$allRoles,
      _this = this;

  var field = {};

  if (props.newFieldData) {
    field = _.cloneDeep(props.newFieldData);
  } else {
    field = _.cloneDeep(props.data[props.editId]);
    if (field.locals && Object.keys(field.locals).length) Object.keys(field.locals).forEach(function (local) {
      if (local && Object.keys(local).length) field.config = _extends({}, field.config, {}, field.locals[local]);
    });
  }

  var editId = (props == null ? void 0 : props.editId) || "83b39886-da74-4654-ae7d-e4d427082d48";
  var hiddenRoles = (props == null ? void 0 : (_props$data = props.data) == null ? void 0 : (_props$data$editId = _props$data[editId]) == null ? void 0 : (_props$data$editId$co = _props$data$editId.config) == null ? void 0 : _props$data$editId$co.hiddenRoles) || [];
  var updatedRoles = [];
  (_props$allRoles = props.allRoles) == null ? void 0 : _props$allRoles.forEach(function (role) {
    updatedRoles.push(_extends({}, role, {
      label: role == null ? void 0 : role.name,
      value: role == null ? void 0 : role.id
    }));
  });

  var renderFieldForms = function renderFieldForms() {
    switch (field.type) {
      case 'checkbox':
        return /*#__PURE__*/React.createElement(Checkbox, {
          data: field,
          allRoles: updatedRoles,
          hiddenRoles: hiddenRoles,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 42,
            columnNumber: 11
          }
        });

      case 'radio':
        return /*#__PURE__*/React.createElement(Radio, {
          data: field,
          allRoles: updatedRoles,
          hiddenRoles: hiddenRoles,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 46,
            columnNumber: 11
          }
        });

      case 'content':
        return /*#__PURE__*/React.createElement(Content, {
          data: field,
          allRoles: updatedRoles,
          hiddenRoles: hiddenRoles,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 50,
            columnNumber: 13
          }
        });

      case 'date':
        return /*#__PURE__*/React.createElement(Date, {
          data: field,
          allRoles: updatedRoles,
          hiddenRoles: hiddenRoles,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 54,
            columnNumber: 13
          }
        });

      case 'file':
        return /*#__PURE__*/React.createElement(File, {
          data: field,
          allRoles: updatedRoles,
          hiddenRoles: hiddenRoles,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 58,
            columnNumber: 13
          }
        });

      case 'image':
        return /*#__PURE__*/React.createElement(Image, {
          data: field,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 62,
            columnNumber: 13
          }
        });

      case 'list':
        return /*#__PURE__*/React.createElement(List, {
          data: field,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 66,
            columnNumber: 13
          }
        });

      case 'quiz':
        return /*#__PURE__*/React.createElement(Quiz, {
          data: field,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 70,
            columnNumber: 13
          }
        });

      case 'select':
        return /*#__PURE__*/React.createElement(Select, {
          data: field,
          allRoles: updatedRoles,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 74,
            columnNumber: 13
          }
        });

      case 'signature':
        return /*#__PURE__*/React.createElement(Signature, {
          data: field,
          allRoles: updatedRoles,
          hiddenRoles: hiddenRoles,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 78,
            columnNumber: 13
          }
        });

      case 'survey':
        return /*#__PURE__*/React.createElement(Survey, {
          data: field,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 82,
            columnNumber: 13
          }
        });

      case 'text':
        return /*#__PURE__*/React.createElement(TextField, {
          data: field,
          allRoles: updatedRoles,
          hiddenRoles: hiddenRoles,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 86,
            columnNumber: 13
          }
        });

      case 'video':
        return /*#__PURE__*/React.createElement(Video, {
          data: field,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 90,
            columnNumber: 13
          }
        });

      case 'section':
        return /*#__PURE__*/React.createElement(Section, {
          data: field,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 93,
            columnNumber: 16
          }
        });

      default:
        return /*#__PURE__*/React.createElement("div", {
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 96,
            columnNumber: 11
          }
        }, "Something magical happened");
    }
  };

  return /*#__PURE__*/React.createElement("div", {
    className: "position-relative ahfb-width-full",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 101,
      columnNumber: 5
    }
  }, renderFieldForms());
}

var mapStateToProps = function mapStateToProps(state) {
  return {
    newFieldData: state.form.newFieldData,
    editId: state.toolbar.editId,
    data: state.form.data,
    allRoles: state.form.allRoles
  };
};

var mapDispatchToProps = function mapDispatchToProps(dispatch) {
  return {};
};

export default connect(mapStateToProps, mapDispatchToProps)(EditField);
